pub const fn settings_help() -> &'static SettingsHelpExpand description
Returns the shared settings catalogue used by host, CLI, MCP and NAPI.
pub const fn settings_help() -> &'static SettingsHelpReturns the shared settings catalogue used by host, CLI, MCP and NAPI.